@@ -7,7 +7,13 @@ import time
 import sys
 
 
-__version__ = '1.0'
+__version__ = '1.0.1'
+
+
+try:
+    import pathlib
+except ImportError:
+    pathlib = None
 
 
 logger = logging.getLogger('usagestats')
@@ -137,6 +143,8 @@ class Stats(object):
 
         if ssl_verify is None or isinstance(ssl_verify, str):
             self.ssl_verify = ssl_verify
+        elif pathlib and isinstance(ssl_verify, pathlib.Path):
+            self.ssl_verify = str(ssl_verify)
         elif isinstance(ssl_verify, bytes):  # bytes on PY3
             self.ssl_verify = ssl_verify.decode('utf-8')
         else:  # unicode on PY2
@@ -336,8 +344,8 @@ class Stats(object):
         if not self.sending:
             fullname = os.path.join(self.location, filename)
             with open(fullname, 'wb') as fp:
-                for l in generator():
-                    fp.write(l)
+                for line in generator():
+                    fp.write(line)
 
             # Show prompt
             sys.stderr.write(self.prompt.prompt)
@@ -374,8 +382,8 @@ class Stats(object):
             logger.warning("Couldn't upload report: %s", str(e))
             fullname = os.path.join(self.location, filename)
             with open(fullname, 'wb') as fp:
-                for l in generator():
-                    fp.write(l)
+                for line in generator():
+                    fp.write(line)
         else:
             try:
                 r.raise_for_status()
